@@ -24,20 +24,21 @@ int RESIZE(
     unsigned long new_height,
     int alpha_flag)
 {
+	unsigned int startx, endx;
+	unsigned int starty, endy;
+	unsigned int i, j, x, y;
+
 	unsigned char *bitmap_buffer2;
-	// if there is an Alpha channel too beside RGB
-	// then we need to allocate more memory for Alpha channel
-	// not 3x but 5x more than the number of pixels in image
+	/* if there is an Alpha channel beside the RGB too */
+	/* then i need to allocate more memory for Alpha channel */
+	/* not 3x but 5x more than the number of pixels in image */
 	if (alpha_flag) { alpha_flag = 2; }
-	//allocate memory
+	/*allocate memory */
 	/* print info */ STRING_PRINTV("allocating memory for uncompressed bitmap image\n");
-	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) );
+	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) * sizeof (*bitmap_buffer2));
 	if (bitmap_buffer2 == 0) return 1;
 
 	/* print info */ STRING_PRINTV("resizing image\n");
-	int startx, endx;
-	int starty, endy;
-	int i, j, x, y;
 
 	#ifdef __OPENMP__
 	#pragma omp parallel for private(i, j, x, y, startx, starty, endx, endy) num_threads(max_threads)
@@ -46,11 +47,6 @@ int RESIZE(
 
 		for (i=0; i<new_width; i++){
 
-			startx = *image_width  * i     / new_width;
-			endx   = *image_width  * (i+1) / new_width;
-			starty = *image_height * j     / new_height;
-			endy   = *image_height * (j+1) / new_height;
-
 			long addr = 0;
 			long rgb_avg_r = 0;
 			long rgb_avg_g = 0;
@@ -58,6 +54,11 @@ int RESIZE(
 			long rgb_avg_a = 0;
 			long rgb_counter = 0;
 
+			startx = *image_width  * i     / new_width;
+			endx   = *image_width  * (i+1) / new_width;
+			starty = *image_height * j     / new_height;
+			endy   = *image_height * (j+1) / new_height;
+
 			for (y=starty; y<endy; y++){
 				for (x=startx; x<endx; x++){
 
@@ -107,21 +108,21 @@ int ROTATE90(
     unsigned long *image_height,
     int alpha_flag)
 {
+	unsigned char *bitmap_buffer2;
+	unsigned int x, y;
+
 	unsigned long new_width;
     	unsigned long new_height;
 	new_width = *image_width;
 	new_height = *image_height;
 
-	unsigned char *bitmap_buffer2;
-
-	//allocate memory
+	/*allocate memory */
 	if (alpha_flag) { alpha_flag = 2; }
 	/* print info */ STRING_PRINTV("allocating memory for uncompressed bitmap image\n");
-	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) );
+	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) * sizeof (*bitmap_buffer2));
 	if (bitmap_buffer2 == 0) return 1;
 
 	/* print info */ STRING_PRINTV("rotating image with 90\n");
-	int x, y;
 
 	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y) num_threads(max_threads)
@@ -167,15 +168,16 @@ int ROTATE180(
     unsigned long *image_height,
     int alpha_flag)
 {
-	/* print info */ STRING_PRINTV("rotating image with 180\n");
+	int x, y, x_max, y_max, y_odd;
+
 	unsigned long new_width;
 	unsigned long new_height;
 	new_width = *image_width;
 	new_height = *image_height;
 
-	int x, y, x_max, y_max, y_odd;
+	/* print info */ STRING_PRINTV("rotating image with 180\n");
 
-	// is the number of lines an odd number?
+	/* is the number of lines an odd number? */
 	y_odd = new_height & 1;
 	y_max = new_height/2 + y_odd;
 
@@ -185,8 +187,8 @@ int ROTATE180(
 	for (y=0; y<y_max; y++){
 
 		x_max = new_width;
-		// if the height is an odd number, then the flipping should go only till the middle of the width
-		// in the middle line
+		/* if the height is an odd number, then the flipping should go only to the middle of the width */
+		/* in the middle line */
 		if ((y_odd) && (y == y_max-1)){ x_max = new_width/2; }
 
 		for (x=0; x<x_max; x++){
@@ -236,21 +238,21 @@ int ROTATE270(
     unsigned long *image_height,
     int alpha_flag)
 {
+	unsigned char *bitmap_buffer2;
+	unsigned int x, y;
+
 	unsigned long new_width;
     	unsigned long new_height;
 	new_width = *image_width;
 	new_height = *image_height;
 
-	unsigned char *bitmap_buffer2;
-
-	//allocate memory
+	/*allocate memory */
 	if (alpha_flag) { alpha_flag = 2; }
 	/* print info */ STRING_PRINTV("allocating memory for uncompressed bitmap image\n");
-	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) );
+	bitmap_buffer2 = malloc(new_width * new_height * (3 + alpha_flag) * sizeof (*bitmap_buffer2));
 	if (bitmap_buffer2 == 0) return 1;
 
 	/* print info */ STRING_PRINTV("rotating image with 270\n");
-	int x, y;
 
 	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y) num_threads(max_threads)
@@ -296,13 +298,14 @@ int FLIPX(
     unsigned long *image_height,
     int alpha_flag)
 {
-	/* print info */ STRING_PRINTV("flipping image horizontally\n");
+	unsigned int x, y;
+
 	unsigned long new_width;
     	unsigned long new_height;
 	new_width = *image_width;
 	new_height = *image_height;
 
-	int x, y;
+	/* print info */ STRING_PRINTV("flipping image horizontally\n");
 
 	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y) num_threads(max_threads)
@@ -356,13 +359,14 @@ int FLIPY(
     unsigned long *image_height,
     int alpha_flag)
 {
-	/* print info */ STRING_PRINTV("flipping image vertically\n");
+	unsigned int x, y;
+
 	unsigned long new_width;
     	unsigned long new_height;
 	new_width = *image_width;
 	new_height = *image_height;
 
-	int x, y;
+	/* print info */ STRING_PRINTV("flipping image vertically\n");
 
 	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y) num_threads(max_threads)
